"""rlottie-python"""
__version__ = "1.2.0"

from .rlottie_wrapper import LottieAnimation
